pub struct ActivationCondition {
pub always: Option<bool>,
pub workspace_member: Vec<String>,
pub runtime_type: Vec<String>,
pub cuenv_source: Vec<String>,
pub secrets_provider: Vec<String>,
pub provider_config: Vec<String>,
pub task_command: Vec<String>,
pub task_labels: Vec<String>,
pub environment: Vec<String>,
}Expand description
Activation condition for contributors All specified conditions must be true (AND logic)
Fields
always: Option<bool>Always active (no conditions)
workspace_member: Vec<String>Workspace membership detection (active if project is member of these workspace types) Values: “npm”, “bun”, “pnpm”, “yarn”, “cargo”, “deno”
runtime_type: Vec<String>Runtime type detection (active if project uses any of these runtime types) Values: “nix”, “devenv”, “container”, “dagger”, “oci”, “tools”
cuenv_source: Vec<String>Cuenv source mode detection (for cuenv installation strategy) Values: “git”, “nix”, “homebrew”, “release”, “native”, “artifact”
secrets_provider: Vec<String>Secrets provider detection (active if environment uses any of these providers) Values: “onepassword”, “aws”, “vault”, “azure”, “gcp”
provider_config: Vec<String>Provider configuration detection (active if these config paths are set) Path format: “github.cachix”, “github.trustedPublishing.cratesIo”
task_command: Vec<String>Task command detection (active if any task uses these commands)
task_labels: Vec<String>Task label detection (active if any task has these labels)
environment: Vec<String>Environment name matching (active only in these environments)