Environment management for cuenv
This module handles environment variables from CUE configurations, including extraction, propagation, and environment-specific overrides.
Structs
- Env
- Environment configuration with environment-specific overrides Based on schema/env.cue
- EnvVar
With Policies - Environment variable with optional access policies
- Environment
- Runtime environment variables for task execution
- Policy
- Policy for controlling environment variable access
Enums
- EnvPart
- A part of an interpolated environment variable value. Can be a literal string or a secret that needs runtime resolution.
- EnvValue
- Environment variable values can be strings, integers, booleans, secrets, interpolated arrays, or values with policies. When exported to actual environment, these will always be strings.
- EnvValue
Simple - Simple environment variable values (non-recursive)