Module affected

Module affected 

Affected detection utilities for tasks and files.

This module provides utilities for determining if tasks are affected by file changes, used by CI pipelines and incremental builds.

Design Philosophy

  • Tasks with inputs are affected if any input pattern matches changed files
  • Tasks with NO inputs are always considered affected (we can’t determine what affects them)
  • This is the safe behavior - if we can’t determine, we run the task

Traits

AffectedBy
Trait for types that can determine if they are affected by file changes.

Functions

build_glob_set
Build a GlobSet from multiple patterns for efficient batch matching.
matches_pattern
Check if any of the given files match a pattern.